@@ -117,7 +117,8 @@ known_schema_hashes = {
 	17: '161428ee97a00e3bf56168c3a15b7b50',
 	18: 'a0f9efcabdecfb4ddb6d8c0b69c02092',
 	#19: '419e5225259c53dd36ad80d82066ff02'	# 19.0 only
-	19: '9765373098b03fb208332498f34cd4b5'
+	#19: '9765373098b03fb208332498f34cd4b5' # until 19.11
+	19: '57f009a159f55f77525cc0291e0c8b60' # starting with 19.12
 }
 
 map_schema_hash2version = {
@@ -138,8 +139,9 @@ map_schema_hash2version = {
 	'0bcf44ca22c479b52976e5eda1de8161': 16,
 	'161428ee97a00e3bf56168c3a15b7b50': 17,
 	'a0f9efcabdecfb4ddb6d8c0b69c02092': 18,
-	#'419e5225259c53dd36ad80d82066ff02': 19	# 19.0. only
-	'9765373098b03fb208332498f34cd4b5': 19
+	#'419e5225259c53dd36ad80d82066ff02': 19	# 19.0 only
+	#'9765373098b03fb208332498f34cd4b5': 19 # until 19.11
+	'57f009a159f55f77525cc0291e0c8b60': 19 # starting with 19.12
 }
 
 map_client_branch2required_db_version = {
@@ -184,7 +186,16 @@ order by
 
 # only works for single-column FKs but that's fine
 # needs gm-dbo, any-doc won't work
-SQL_foreign_key_name = u"""SELECT tc.constraint_schema, tc.constraint_name
+SQL_foreign_key_name = u"""SELECT
+	tc.*,
+	tc.constraint_schema,
+	tc.constraint_name,
+	tc.table_schema as source_schema,
+	tc.table_name as source_table,
+	kcu.column_name as source_column,
+	ccu.table_schema as target_schema,
+	ccu.table_name as target_table,
+	ccu.column_name as target_column
 FROM
 	information_schema.table_constraints tc
 		INNER JOIN information_schema.constraint_column_usage ccu USING (constraint_catalog, constraint_schema, constraint_name)
@@ -1555,7 +1566,7 @@ def get_raw_connection(dsn=None, verbose=False, readonly=True):
 		except:
 			pass
 		if verbose:
-			__log_PG_settings(curs=curs)
+			_log_PG_settings(curs=curs)
 		curs.close()
 		conn.commit()
 
@@ -1818,7 +1829,7 @@ def sanity_check_database_settings():
 
 	return 0, u''
 #------------------------------------------------------------------------
-def __log_PG_settings(curs=None):
+def _log_PG_settings(curs=None):
 	# don't use any of the run_*()s since that might
 	# create a loop if we fail here
 	# FIXME: use pg_settings
@@ -1833,6 +1844,19 @@ def __log_PG_settings(curs=None):
 		return False
 	for setting in settings:
 		_log.debug(u'PG option [%s]: %s', setting[0], setting[1])
+
+	try:
+		curs.execute(u'select pg_available_extensions()')
+	except:
+		_log.exception(u'cannot log available PG extensions')
+		return False
+	extensions = curs.fetchall()
+	if extensions is None:
+		_log.error(u'no PG extensions available')
+		return False
+	for ext in extensions:
+		_log.debug(u'PG extension: %s', ext[0])
+
 	return True
 #========================================================================
 def make_pg_exception_fields_unicode(exc):
